/*!
*	\addtogroup ComuniLPC
*	\{
*/

/*!
*   \addtogroup FunzioniComuni	Funzioni comuni
*	\{
*/

#include <stdio.h>

/*!
*	\brief Stampa l'errore
*
*	Scrive un codice di errore, la funzione chiamante e un messaggio di errore.
*	L'errore viene stampato su stderr.
*
*	Il parametro \a ErrorCode  il codice di errore. \a Func e' il nome della
*	funzione che sta intercettando l'errore e \a Msg e' il messaggio di errore.
*
*	Da notare che \a Func non  il nome della funzione che ha generato un 
*	errore, ma il nome della funzione che lo ha ricevuto.\n
*	Il messaggio di errore e' una stringa che puo' contenere le informazioni 
*	aggiuntive per il miglior monitoraggio dell'errore.
*
*	I codici di errore delle funzioni da implementare sono gi definiti in LPC_Include.h 
*
*	
*	Tutti i codice di errore sono negativi. 
*
*	Esempio di gestione dell'errore:
*	\code
*	int Insert()
*	{
*	....
*		if (NumFields < 0)
*		{
*			char Err[256];
*			(void) sprintf(Err, "Errore parametro NumFields negativo");
*			LPC_GestioneErrore(LPC_BAD_ARG, "Insert", Err);
*			< Liberare tutta la memoria allocata in questa funzione >
*			return(LPC_BAD_ARG);
*		}
*	....
*	}
*	\endcode
*
*	Esempio di gestione dell'errore su allocazione memoria:
*	\code
*	int Insert()
*	{
*	....
*		buf = calloc(10, sizeof(long));
*		if (!buf)
*		{
*			char Err[256];
*			(void) sprintf(Err, "Errore allocazione memoria");
*			LPC_GestioneErrore(LPC_NO_MEMORY, "Insert", Err);
*			< Liberare tutta la memoria allocata in questa funzione >
*			return(LPC_NO_MEMORY);
*		}
*	....
*	}
*	\endcode

*	Esempio di gestione dell'errore ritornato da una chiamata ad una funzione di sistema:
*	\code
*	int Insert()
*	{
*	....
*		ret = fwrite(buffer, sizeof(char), len, fp);
*		if (ret != len)
*		{
*			char Err[256];
*			(void) sprintf(Err, "Errore di sistema [%d] in scrittura su file:[%s]", errno, strerror(errno));
*			LPC_GestioneErrore(LPC_ERR_WRITE, "Insert", Err);
*			< Liberare tutta la memoria allocata in questa funzione >
*			return(LPC_ERR_WRITE);
*		}
*	....
*	}
*	\endcode
*
*	Esempio di gestione errore per una chiamata ad una funzione interna:
*	\code
*	int Insert()
*	{
*	... 
*		ret = GetDBFInfo(handle, &DBFInfo);
*		if (ret != LPC_OK)
*		{
*			char Err[256];
*			(void) sprintf(Err, "Errore chiamata alla GetDBFInfo:[%d]", ret);
*			LPC_GestioneErrore(ret, "Insert", Err);
*			return(ret);
*		}
*	....
*	}
*	\endcode
*
*	\param[in] ErrorCode	Codice dell'errore
*	\param[in] Func			Funzione da cui viene la chiamata
*	\param[in] Msg			Messaggio di errore
*
*	\author 	Gianni Campanile
*	\author 	Stefano Guerrini
*	\author 	Andrea Sterbini
*	\date 		Gennaio 2006
*	\version 	1.0
**/
void LPC_GestioneErrore(int ErrorCode, char *Func, char *Msg)
{
	
	fprintf(stderr, "Errore [%d] in [%s]-->[%s]\n", ErrorCode, Func, Msg);

}


/*! \} */	// Fine gruppo Funzioni

/*! \} */	// Fine gruppo LPC

